# This file contains CGAL makefile settings for the following platform:
# OS:				i686_Linux-2.6
# COMPILER:			GNU 4.1.3
# BOOST:	supported (1.34.0)
# BOOST_PROGRAM_OPTIONS:	supported (1.34.0)
# BOOST_BIMAP:	not supported
# X11:	supported (11.0)
# GMP:	supported (4.2.1)
# GMPXX:	supported (4.2.1)
# MPFR:	supported (2.3.0)
# ZLIB:	supported (1.2.3.3)
# BLAS:	supported (unknown version)
# LAPACK:	supported (unknown version)
# ATLAS:	supported (unknown version)
# LEDA:	not supported
# LEDAWIN:	not supported
# OPENGL:	supported (2.1)
# QT:	supported (3.3.7)
# TAUCS:	not supported

#---------------------------------------------------------------------#
#                    include/lib directory settings
#---------------------------------------------------------------------#

CGAL_INCL_DIR = /usr/include
CGAL_LIB_DIR = /usr/lib

#---------------------------------------------------------------------#
#                    os/compiler description
#---------------------------------------------------------------------#

CGAL_OS_COMPILER = i686_Linux-2.6_g++-4.1.3

#---------------------------------------------------------------------#
#                    filename related flags
#---------------------------------------------------------------------#

OBJ_EXT = .o
EXE_EXT = 
LIB_SUFFIX = 

#---------------------------------------------------------------------#
#                    some specific compiler flags
#---------------------------------------------------------------------#

OBJ_OPT = -c
DEBUG_OPT = -g
START_LD_OPT = 
LIBPATH_OPT = -L
LIB_OPT =  -l
RANLIB = /bin/cat >/dev/null

#---------------------------------------------------------------------#
#                    suffixes and rules
#---------------------------------------------------------------------#

.SUFFIXES:   .cpp .clean

.C.clean:
	rm -f $* $*.o $*.moc


.cpp.clean:
	rm -f $* $*.o $*.moc


#---------------------------------------------------------------------#
#                    compiler
#---------------------------------------------------------------------#

CGAL_CXX = g++

#---------------------------------------------------------------------#
#                    compiler flags
#---------------------------------------------------------------------#

# For more information about the compiler flags see the installation guide.

# compiler specific configuration dir
CGAL_INCL_CONF_DIR = /usr/include

# *** Fill in any additional compiler flags you need ***
CUSTOM_CXXFLAGS = 

CGAL_SHARED_LIB_EXT = .so

# *** compiler flags for feature BOOST ***
BOOST_CXXFLAGS = 

# *** compiler flags for feature BOOST_PROGRAM_OPTIONS ***
BOOST_PROGRAM_OPTIONS_CXXFLAGS = 

# *** compiler flags for feature X11 ***
X11_CXXFLAGS = 

# *** compiler flags for feature GMP ***
GMP_CXXFLAGS = 

# *** compiler flags for feature GMPXX ***
GMPXX_CXXFLAGS = 

# *** compiler flags for feature MPFR ***
MPFR_CXXFLAGS = 

# *** compiler flags for feature ZLIB ***
ZLIB_CXXFLAGS = 

# *** compiler flags for feature BLAS ***
BLAS_CXXFLAGS = 

# *** compiler flags for feature LAPACK ***
LAPACK_CXXFLAGS = 

# *** compiler flags for feature ATLAS ***
ATLAS_CXXFLAGS = 

# *** compiler flags for feature OPENGL ***
OPENGL_CXXFLAGS = 

# *** compiler flags for feature QT ***
QT_CXXFLAGS =  \
	-I/usr/include/qt3 

# *** compiler flags for package BOOST ***
BOOST_PKG_CXXFLAGS = 

# *** compiler flags for package BOOST_PROGRAM_OPTIONS ***
BOOST_PROGRAM_OPTIONS_PKG_CXXFLAGS = 

# *** compiler flags for package X11 ***
X11_PKG_CXXFLAGS = 

# *** compiler flags for package GMP ***
GMP_PKG_CXXFLAGS = 

# *** compiler flags for package GMPXX ***
GMPXX_PKG_CXXFLAGS = 

# *** compiler flags for package MPFR ***
MPFR_PKG_CXXFLAGS = 

# *** compiler flags for package ZLIB ***
ZLIB_PKG_CXXFLAGS = 

# *** compiler flags for package BLASGCCATLAS ***
BLASGCCATLAS_PKG_CXXFLAGS =  \
	-DCGAL_USE_F2C

# *** compiler flags for package OPENGL ***
OPENGL_PKG_CXXFLAGS = 

# *** compiler flags for package LAPACK ***
LAPACK_PKG_CXXFLAGS =  \
	-DCGAL_USE_F2C

# *** compiler flags for package QT3MT ***
QT3MT_PKG_CXXFLAGS = 

# *** complete compiler flags for feature BOOST ***
ALL_BOOST_CXXFLAGS = $(BOOST_CXXFLAGS) $(BOOST_PKG_CXXFLAGS)

# *** complete compiler flags for feature BOOST_PROGRAM_OPTIONS ***
ALL_BOOST_PROGRAM_OPTIONS_CXXFLAGS = $(BOOST_PROGRAM_OPTIONS_CXXFLAGS) $(BOOST_PROGRAM_OPTIONS_PKG_CXXFLAGS)

# *** complete compiler flags for feature X11 ***
ALL_X11_CXXFLAGS = $(X11_CXXFLAGS) $(X11_PKG_CXXFLAGS)

# *** complete compiler flags for feature GMP ***
ALL_GMP_CXXFLAGS = $(GMP_CXXFLAGS) $(GMP_PKG_CXXFLAGS)

# *** complete compiler flags for feature GMPXX ***
ALL_GMPXX_CXXFLAGS = $(GMPXX_CXXFLAGS) $(GMPXX_PKG_CXXFLAGS)

# *** complete compiler flags for feature MPFR ***
ALL_MPFR_CXXFLAGS = $(MPFR_CXXFLAGS) $(MPFR_PKG_CXXFLAGS)

# *** complete compiler flags for feature ZLIB ***
ALL_ZLIB_CXXFLAGS = $(ZLIB_CXXFLAGS) $(ZLIB_PKG_CXXFLAGS)

# *** complete compiler flags for feature BLAS ***
ALL_BLAS_CXXFLAGS = $(BLAS_CXXFLAGS) $(BLASGCCATLAS_PKG_CXXFLAGS)

# *** complete compiler flags for feature LAPACK ***
ALL_LAPACK_CXXFLAGS = $(LAPACK_CXXFLAGS) $(LAPACK_PKG_CXXFLAGS)

# *** complete compiler flags for feature ATLAS ***
ALL_ATLAS_CXXFLAGS = $(ATLAS_CXXFLAGS) $(BLASGCCATLAS_PKG_CXXFLAGS)

# *** complete compiler flags for feature OPENGL ***
ALL_OPENGL_CXXFLAGS = $(OPENGL_CXXFLAGS) $(OPENGL_PKG_CXXFLAGS)

# *** complete compiler flags for feature QT ***
ALL_QT_CXXFLAGS = $(QT_CXXFLAGS) $(QT3MT_PKG_CXXFLAGS)

# *** to work around the long-name-problem with sun as/ld
LONG_NAME_PROBLEM_CXXFLAGS =

CGAL_CXXFLAGS = $(strip \
	-Wall -frounding-math \
	$(CUSTOM_CXXFLAGS) \
	$(BOOST_CXXFLAGS) \
	$(BOOST_PROGRAM_OPTIONS_CXXFLAGS) \
	$(X11_CXXFLAGS) \
	$(GMP_CXXFLAGS) \
	$(GMPXX_CXXFLAGS) \
	$(MPFR_CXXFLAGS) \
	$(ZLIB_CXXFLAGS) \
	$(BLAS_CXXFLAGS) \
	$(LAPACK_CXXFLAGS) \
	$(ATLAS_CXXFLAGS) \
	$(OPENGL_CXXFLAGS) \
	$(QT_CXXFLAGS) \
	$(BOOST_PKG_CXXFLAGS) \
	$(BOOST_PROGRAM_OPTIONS_PKG_CXXFLAGS) \
	$(X11_PKG_CXXFLAGS) \
	$(GMP_PKG_CXXFLAGS) \
	$(GMPXX_PKG_CXXFLAGS) \
	$(MPFR_PKG_CXXFLAGS) \
	$(ZLIB_PKG_CXXFLAGS) \
	$(BLASGCCATLAS_PKG_CXXFLAGS) \
	$(OPENGL_PKG_CXXFLAGS) \
	$(LAPACK_PKG_CXXFLAGS) \
	$(QT3MT_PKG_CXXFLAGS) \
	)

CGAL_WINLIB_CXXFLAGS = \
	$(CGAL_LIB_CXXFLAGS)


#---------------------------------------------------------------------#
#                    linker flags
#---------------------------------------------------------------------#

# *** Flag to define the name of the produced executable ***
EXE_OPT = -o $(SAVESTHEBLANK)

# *** libpath flags for feature BOOST ***
BOOST_LIBPATHFLAGS = 

# *** libpath flags for feature BOOST_PROGRAM_OPTIONS ***
BOOST_PROGRAM_OPTIONS_LIBPATHFLAGS = 

# *** libpath flags for feature X11 ***
X11_LIBPATHFLAGS = 

# *** libpath flags for feature GMP ***
GMP_LIBPATHFLAGS = 

# *** libpath flags for feature GMPXX ***
GMPXX_LIBPATHFLAGS = 

# *** libpath flags for feature MPFR ***
MPFR_LIBPATHFLAGS = 

# *** libpath flags for feature ZLIB ***
ZLIB_LIBPATHFLAGS = 

# *** libpath flags for feature BLAS ***
BLAS_LIBPATHFLAGS = 

# *** libpath flags for feature LAPACK ***
LAPACK_LIBPATHFLAGS = 

# *** libpath flags for feature ATLAS ***
ATLAS_LIBPATHFLAGS = 

# *** libpath flags for feature OPENGL ***
OPENGL_LIBPATHFLAGS = 

# *** libpath flags for feature QT ***
QT_LIBPATHFLAGS = 

# *** libpath flags for CGAL ***
CGAL_LIBPATHFLAGS = $(strip \
	$(BOOST_LIBPATHFLAGS) \
	$(BOOST_PROGRAM_OPTIONS_LIBPATHFLAGS) \
	$(X11_LIBPATHFLAGS) \
	$(GMP_LIBPATHFLAGS) \
	$(GMPXX_LIBPATHFLAGS) \
	$(MPFR_LIBPATHFLAGS) \
	$(ZLIB_LIBPATHFLAGS) \
	$(BLAS_LIBPATHFLAGS) \
	$(LAPACK_LIBPATHFLAGS) \
	$(ATLAS_LIBPATHFLAGS) \
	$(OPENGL_LIBPATHFLAGS) \
	$(QT_LIBPATHFLAGS) \
	)

# *** Fill in any additional linker flags you need ***
CUSTOM_LDFLAGS = 

# *** to work around the long-name-problem with sun as/ld
LONG_NAME_PROBLEM_LDFLAGS =

CGAL_LIBPATH =

CGAL_LD_LIBPATH = $(CGAL_LIBPATHFLAGS)

# *** linker flags for package BOOST ***
BOOST_PKG_LDFLAGS = 

# *** linker flags for package BOOST_PROGRAM_OPTIONS ***
BOOST_PROGRAM_OPTIONS_PKG_LDFLAGS =  \
	 -lboost_program_options-mt 

# *** linker flags for package X11 ***
X11_PKG_LDFLAGS =  \
	 -lX11 

# *** linker flags for package GMP ***
GMP_PKG_LDFLAGS =  \
	 -lgmp 

# *** linker flags for package GMPXX ***
GMPXX_PKG_LDFLAGS =  \
	 -lgmpxx 

# *** linker flags for package MPFR ***
MPFR_PKG_LDFLAGS =  \
	 -lmpfr 

# *** linker flags for package ZLIB ***
ZLIB_PKG_LDFLAGS =  \
	 -lz 

# *** linker flags for package BLASGCCATLAS ***
BLASGCCATLAS_PKG_LDFLAGS =  \
	 -llapack  \
	 -lf77blas  \
	 -lcblas  \
	 -latlas  \
	 -lg2c 

# *** linker flags for package OPENGL ***
OPENGL_PKG_LDFLAGS =  \
	 -lGL  \
	 -lGLU 

# *** linker flags for package LAPACK ***
LAPACK_PKG_LDFLAGS =  \
	 -llapack 

# *** linker flags for package QT3MT ***
QT3MT_PKG_LDFLAGS =  \
	 -lqt-mt 

# *** linker flags for CGAL ***
CGAL_CGAL_LDFLAGS = \
	 -lCGAL 

CGAL_LDFLAGS = $(strip \
	$(CGAL_LD_LIBPATH)  \
	$(CUSTOM_LDFLAGS) \
	$(CGAL_CGAL_LDFLAGS) \
	 -lCGALcore++  \
	 -lCGALQt  \
	 -lCGALimageIO  \
	 -lCGALPDB  \
	$(QT3MT_PKG_LDFLAGS) \
	$(LAPACK_PKG_LDFLAGS) \
	$(OPENGL_PKG_LDFLAGS) \
	$(BLASGCCATLAS_PKG_LDFLAGS) \
	$(ZLIB_PKG_LDFLAGS) \
	$(MPFR_PKG_LDFLAGS) \
	$(GMPXX_PKG_LDFLAGS) \
	$(GMP_PKG_LDFLAGS) \
	$(X11_PKG_LDFLAGS) \
	$(BOOST_PROGRAM_OPTIONS_PKG_LDFLAGS) \
	$(BOOST_PKG_LDFLAGS) \
	 -lm  \
	)

# *** linker flags for feature BOOST ***
BOOST_LDFLAGS = $(BOOST_PKG_LDFLAGS)

# *** linker flags for feature BOOST_PROGRAM_OPTIONS ***
BOOST_PROGRAM_OPTIONS_LDFLAGS = $(BOOST_PROGRAM_OPTIONS_PKG_LDFLAGS)

# *** linker flags for feature X11 ***
X11_LDFLAGS = $(X11_PKG_LDFLAGS)

# *** linker flags for feature GMP ***
GMP_LDFLAGS = $(GMP_PKG_LDFLAGS)

# *** linker flags for feature GMPXX ***
GMPXX_LDFLAGS = $(GMPXX_PKG_LDFLAGS)

# *** linker flags for feature MPFR ***
MPFR_LDFLAGS = $(MPFR_PKG_LDFLAGS)

# *** linker flags for feature ZLIB ***
ZLIB_LDFLAGS = $(ZLIB_PKG_LDFLAGS)

# *** linker flags for feature BLAS ***
BLAS_LDFLAGS = $(BLASGCCATLAS_PKG_LDFLAGS)

# *** linker flags for feature LAPACK ***
LAPACK_LDFLAGS = $(LAPACK_PKG_LDFLAGS)

# *** linker flags for feature ATLAS ***
ATLAS_LDFLAGS = $(BLASGCCATLAS_PKG_LDFLAGS)

# *** linker flags for feature OPENGL ***
OPENGL_LDFLAGS = $(OPENGL_PKG_LDFLAGS)

# *** linker flags for feature QT ***
QT_LDFLAGS = $(QT3MT_PKG_LDFLAGS)

# *** Qt meta object compiler executable ***
QT_MOC = \
	/usr/share/qt3/bin/moc


#---------------------------------------------------------------------#
#                    commands and flags for creating libraries
#---------------------------------------------------------------------#

CGAL_STATIC_LIBNAME = lib$(LIB_NAME_BASE).a
CGAL_SHARED_LIBNAME = lib$(LIB_NAME_BASE)$(CGAL_SHARED_LIB_EXT)
CGAL_LIB_CXXFLAGS = \
	 -O2 \
	$(CGAL_CXXFLAGS)
CGAL_LIB_LDFLAGS = 

CGAL_STATIC_LIB_CREATE = ar cr ''
CGAL_OBJ_PREFIX = 
CGAL_LIB_DESTINATION = '$(CGAL_LIB_DIR)'
CGAL_SHARED_LIB_CXXFLAGS = \
	-fPIC -O2 \
	$(CGAL_CXXFLAGS)
CGAL_SHARED_LIB_LDFLAGS = $(CGAL_LIBPATHFLAGS) $(CUSTOM_LDFLAGS) 
CGAL_SHARED_LIB_CREATE = $(CGAL_CXX) -shared  -o ''

CGAL_SHARED_LIB_SONAME = -Wl,-soname,$(CGAL_SHARED_LIBNAME).$(SOMAJOR)
CGAL_SHARED_LIBNAME_WITH_SOMAJOR = $(CGAL_SHARED_LIBNAME).$(SOMAJOR)
CGAL_SHARED_LIBNAME_WITH_SOVERSION = $(CGAL_SHARED_LIBNAME).$(SOVERSION)

# *** only used for the testsuite
# *** program used to create stacktrace from coredump
PRINT_STACKTRACE_PROGRAM = gdb


#---------------------------------------------------------------------#
#                    EOF
#---------------------------------------------------------------------#

